@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "acton-mode" "0.4.3"
+(define-package "acton-mode" "20250113.1059"
   "Major mode for editing Acton source code."
   '((emacs "25.1"))
   :url "https://github.com/actonlang/acton-mode"
